@@ -27,12 +27,12 @@ Catalyst::Test - Test Catalyst applications
 
     use Catalyst qw[-Engine=Test];
 
-    __PACKAGE__->action(
-        foo => sub {
+    sub foo : Global {
             my ( $self, $c ) = @_;
             $c->res->output('bar');
-        }
-    );
+    }
+
+    __PACKAGE__->setup();
 
     package main;
 
